==> haskell-th-abstraction-0.2.2.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-abstraction
version: 0.2.2.0
id: th-abstraction-0.2.2.0-HePjPSDyyUMAgNw53miBAc
key: th-abstraction-0.2.2.0-HePjPSDyyUMAgNw53miBAc
license: ISC
copyright: 2017 Eric Mertens
maintainer: emertens@gmail.com
homepage: https://github.com/glguy/th-abstraction
synopsis: Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.
category: Development
author: Eric Mertens
exposed: True
exposed-modules:
    Language.Haskell.TH.Datatype
hidden-modules: Language.Haskell.TH.Datatype.Internal
abi: 0a22e4a1e1e2ae92f296d377ef187e03
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/th-abstraction-0.2.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/th-abstraction-0.2.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/th-abstraction-0.2.2.0
hs-libraries: HSth-abstraction-0.2.2.0-HePjPSDyyUMAgNw53miBAc
depends:
    base-4.9.0.0 containers-0.5.7.1 ghc-prim-0.5.0.0
    template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock
haddock-html: /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-abstraction-0.2.3.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-abstraction
version: 0.2.3.0
id: th-abstraction-0.2.3.0-IC8R8TEnxiaENlxvcI4gyL
key: th-abstraction-0.2.3.0-IC8R8TEnxiaENlxvcI4gyL
license: ISC
copyright: 2017 Eric Mertens
maintainer: emertens@gmail.com
homepage: https://github.com/glguy/th-abstraction
synopsis: Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.
category: Development
author: Eric Mertens
exposed: True
exposed-modules:
    Language.Haskell.TH.Datatype
hidden-modules: Language.Haskell.TH.Datatype.Internal
abi: 4dad5b20070953d7e1ac97d6adee5525
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-abstraction-0.2.3.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-abstraction-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/th-abstraction-0.2.3.0
hs-libraries: HSth-abstraction-0.2.3.0-IC8R8TEnxiaENlxvcI4gyL
depends:
    base-4.9.1.0 containers-0.5.7.1 ghc-prim-0.5.0.0
    template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock
haddock-html: /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
